==> lowcode-editor-skeleton-2.0.5.tgz: package/es/components/settings/components/array-advance-table/index.js <==
import _Button from "antd/es/button";
import _Space from "antd/es/space";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["valueMode", "className", "rowSelectionOptions"],
  _excluded2 = ["drawerProps"];
import { onFieldValueChange } from '@formily/core';
import { FieldContext, observer, RecordsScope, RecursionField, SchemaContext, useField, useFieldSchema } from '@formily/react';
import { isUndef } from '@formily/shared';
import cls from 'classnames';
import React, { forwardRef, useEffect, useMemo, useRef, useState } from 'react';
import useStyle from './style';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
import { ArrayBase } from '@formily/antd-v5';
import { useCommonUI, useSelected } from '../../../../hooks';
import { createIcon } from '@gant-lowcode/lowcode-utils';
import { createPortal } from 'react-dom';
import { useSlot } from '../../context';
import { Action, Addition, BatchRemove, Column, GridManagerContext, indexKey, isColumnComponent, LOWCODE_NODE_ID, Navigation, RowSelectedContext, SidePanel, SortHandle, useAddition, useArrayTableColumns, useArrayTableSources, useBatchRemove, ValueModeContext } from './common';
import { AdvanceContent } from './advance-content';
import { ValidatorSetter } from '../validator-setter';
import { useHandleCellEditChange } from './hooks';
var InternalArrayAdvanceTable = observer(function (_ref) {
  var valueMode = _ref.valueMode,
    className = _ref.className,
    rowSelectionOptions = _ref.rowSelectionOptions,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var ref = useRef(null);
  var field = useField();
  var schema = useFieldSchema();
  var selected = useSelected();
  var _useCommonUI = useCommonUI(),
    AdvanceTable = _useCommonUI.AdvanceTable;
  var _AdvanceTable$useGrid = AdvanceTable.useGrid(),
    gridManagerRef = _AdvanceTable$useGrid.gridManagerRef,
    gridApiRef = _AdvanceTable$useGrid.gridApiRef,
    onGridReady = _AdvanceTable$useGrid.onGridReady;
  var _AdvanceTable$useRowS = AdvanceTable.useRowSelection(gridApiRef, _extends({}, rowSelectionOptions, {
      rowkey: LOWCODE_NODE_ID
    })),
    rowSelection = _AdvanceTable$useRowS.rowSelection,
    clearRowSelection = _AdvanceTable$useRowS.clearRowSelection,
    selectedKeys = _AdvanceTable$useRowS.selectedKeys,
    selectedRows = _AdvanceTable$useRowS.selectedRows;
  schema['x-data'] = 'normal';
  var prefixCls = usePrefixCls('array-avance-table');
  var _useStyle = useStyle(prefixCls),
    wrapSSR = _useStyle[0],
    hashId = _useStyle[1];
  var open = useOpen();
  useMemo(function () {
    if (!valueMode || valueMode === 'normal') return;
    var value = [];
    selected.children.forEach(function (child) {
      var _extends2;
      value.push(_extends({}, child.propsData, (_extends2 = {}, _extends2[LOWCODE_NODE_ID] = child.id, _extends2)));
    });
    field.setValue(value);
  }, []);
  var dataSource = Array.isArray(field.value) ? field.value.slice() : [];
  dataSource.forEach(function (item, index) {
    item[indexKey] = index;
  });
  useEffect(function () {
    var effects = function effects() {
      onFieldValueChange(field.path.toString() + '.*', function (dataField) {
        var value = dataField.value;
        var key = dataField.path.toArr();
        var name = key[0],
          index = key[1],
          path = key.slice(2);
        selected.children.get(index).setPropValue(path.join('.'), value);
      });
    };
    field.form.addEffects('node-children-array-table', effects);
    return function () {
      field.form.removeEffects('node-children-array-table');
    };
  }, [field, selected]);
  var sources = useArrayTableSources(field, schema);
  var columns = useArrayTableColumns(dataSource, field, sources);
  var addition = useAddition(schema);
  var batchRemove = useBatchRemove(schema);
  console.log('---selectedKeys', selectedKeys);
  console.log('---columns', columns);
  console.log('---dataSource', dataSource);
  var handleCellEditChange = useHandleCellEditChange(valueMode, dataSource);
  var handleRowDragEnd = function handleRowDragEnd(params) {
    var overIndex = params.overIndex,
      overNode = params.overNode;
    var node = selected.document.getNodeById(overNode.id);
    var nodeIndex = selected.children.indexOf(node);
    selected.children.insert(node, overIndex > nodeIndex ? overIndex + 1 : overIndex);
  };
  return wrapSSR(/*#__PURE__*/React.createElement(ValueModeContext.Provider, {
    value: valueMode
  }, /*#__PURE__*/React.createElement(GridManagerContext.Provider, {
    value: gridManagerRef
  }, /*#__PURE__*/React.createElement(RowSelectedContext.Provider, {
    value: selectedKeys
  }, /*#__PURE__*/React.createElement("div", {
    ref: ref,
    className: cls(prefixCls, hashId)
  }, /*#__PURE__*/React.createElement(ArrayBase, null, /*#__PURE__*/React.createElement(_Space, {
    className: cls(prefixCls + "-toobar")
  }, addition, batchRemove), /*#__PURE__*/React.createElement(AdvanceTable, _extends({
    editable: true,
    autoHeight: true,
    animateRows: true,
    rowMultiSelectWithClick: false,
    suppressSelectedBox: true,
    stopEditingWhenCellsLoseFocus: true,
    rowDragManaged: true
  }, props, {
    selectionColumnDef: {
      minWidth: 25,
      width: 25,
      maxWidth: 25
    },
    rowkey: LOWCODE_NODE_ID,
    rowSelection: rowSelection,
    onReady: onGridReady,
    className: cls(prefixCls + "-grid", className),
    columns: columns,
    dataSource: dataSource,
    onCellEditChange: handleCellEditChange,
    onRowDragEnd: handleRowDragEnd
  })), sources.map(function (column, key) {
    // 专门用来承接对Column的状态管理
    if (!isColumnComponent(column.schema)) return;
    return /*#__PURE__*/React.createElement(RecursionField, {
      name: column.name,
      schema: column.schema,
      onlyRenderSelf: true,
      key: key
    });
  }), open))))));
});
var isOpenComponent = function isOpenComponent(schema) {
  var _schema$xComponent;
  return ((_schema$xComponent = schema['x-component']) === null || _schema$xComponent === void 0 ? void 0 : _schema$xComponent.indexOf('Open')) > -1;
};
var useOpen = function useOpen() {
  var schema = useFieldSchema();
  return schema.reduceProperties(function (open, schema, key) {
    if (isOpenComponent(schema)) {
      return /*#__PURE__*/React.createElement(RecursionField, {
        schema: schema,
        name: key
      });
    }
    return open;
  }, null);
};
var Open = /*#__PURE__*/forwardRef(function (_ref2, ref) {
  var _array$field, _array$field2;
  var drawerProps = _ref2.drawerProps,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded2);
  var _useSlot = useSlot(),
    slotRef = _useSlot.slotRef;
  var _useState = useState(false),
    open = _useState[0],
    setOpen = _useState[1];
  var showDrawer = function showDrawer() {
    setOpen(true);
  };
  var onClose = function onClose() {
    setOpen(false);
  };
  var _useCommonUI2 = useCommonUI(),
    Drawer = _useCommonUI2.Drawer;
  var self = useField();
  var array = ArrayBase.useArray();
  var prefixCls = usePrefixCls('array-avance-table');
  var _useStyle2 = useStyle(prefixCls),
    wrapSSR = _useStyle2[0],
    hashId = _useStyle2[1];
  if (!array) return null;
  if (((_array$field = array.field) === null || _array$field === void 0 ? void 0 : _array$field.pattern) !== 'editable' && ((_array$field2 = array.field) === null || _array$field2 === void 0 ? void 0 : _array$field2.pattern) !== 'disabled') return null;
  var openButton = wrapSSR(/*#__PURE__*/React.createElement(_Button, _extends({
    type: "ghost"
  }, props, {
    style: _extends({
      padding: '0 6px 0 6px',
      width: 'auto',
      height: 'auto'
    }, props.style),
    disabled: self === null || self === void 0 ? void 0 : self.disabled,
    className: cls(prefixCls + "-open", hashId, self !== null && self !== void 0 && self.disabled ? prefixCls + "-open-disabled" : '', props.className),
    ref: ref,
    onClick: function onClick(e) {
      var _array$props;
      if ((_array$props = array.props) !== null && _array$props !== void 0 && _array$props.disabled) return;
      showDrawer();
      if (props.onClick) {
        props.onClick(e);
      }
    },
    icon: isUndef(props.icon) ? createIcon('fullscreen1') : props.icon
  }), props.title || self.title));
  var drawer = /*#__PURE__*/React.createElement(Drawer, _extends({}, drawerProps, {
    scrollBar: false,
    wrapperBody: false,
    push: false,
    className: cls(prefixCls + "-advance-drawer", drawerProps.className),
    classNames: {
      body: prefixCls + "-advance-drawer-body"
    },
    onClose: onClose,
    open: open
  }), /*#__PURE__*/React.createElement(RecordsScope, {
    getRecords: function getRecords() {
      return array.field.value;
    }
  }, /*#__PURE__*/React.createElement(FieldContext.Provider, {
    value: array.field
  }, /*#__PURE__*/React.createElement(SchemaContext.Provider, {
    value: array.schema
  }, /*#__PURE__*/React.createElement(AdvanceContent, array.field.componentProps)))));
  if (slotRef.current) {
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/createPortal(openButton, slotRef.current), drawer);
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, openButton, drawer);
});
export var ArrayAdvanceTable = Object.assign(ArrayBase.mixin(InternalArrayAdvanceTable), {
  Column: Column,
  Addition: Addition,
  Navigation: Navigation,
  Open: Open,
  ValidatorSetter: ValidatorSetter,
  Action: Action,
  SortHandle: SortHandle,
  SidePanel: SidePanel,
  BatchRemove: BatchRemove
});
ArrayAdvanceTable.displayName = 'ArrayAdvanceTable';
export default ArrayAdvanceTable;

==> lowcode-editor-skeleton-2.0.7.tgz: package/es/components/settings/components/array-advance-table/index.js <==
import _Button from "antd/es/button";
import _Space from "antd/es/space";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["valueMode", "className", "rowSelectionOptions"],
  _excluded2 = ["drawerProps"];
import { FieldContext, RecordsScope, RecursionField, SchemaContext, useField, useFieldSchema, observer } from '@formily/react';
import { isUndef } from '@formily/shared';
import cls from 'classnames';
import React, { forwardRef, memo, useEffect, useMemo, useRef, useState } from 'react';
import useStyle from './style';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
import { ArrayBase, PreviewText } from '@formily/antd-v5';
import { useCommonUI, useSelected } from '../../../../hooks';
import { createIcon } from '@gant-lowcode/lowcode-utils';
import { createPortal } from 'react-dom';
import { useSlot } from '../../context';
import { Action, Addition, BatchRemove, Column, FieldDataSourceContext, GridManagerContext, indexKey, isColumnComponent, LOWCODE_NODE_ID, Navigation, RowSelectedContext, SidePanel, useAddition, useArrayTableColumns, useArrayTableSources, useBatchRemove, ValueModeContext } from './common';
import { AdvanceContent } from './advance-content';
import { useRowDragEnd } from './hooks';
import { onFieldDiffValueChange } from '../../settings-from/utils';
var InternalArrayAdvanceTable = observer(function (_ref) {
  var valueMode = _ref.valueMode,
    className = _ref.className,
    rowSelectionOptions = _ref.rowSelectionOptions,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var ref = useRef(null);
  var field = useField();
  var schema = useFieldSchema();
  var selected = useSelected();
  var _useCommonUI = useCommonUI(),
    AdvanceTable = _useCommonUI.AdvanceTable;
  var _AdvanceTable$useGrid = AdvanceTable.useGrid(),
    gridManagerRef = _AdvanceTable$useGrid.gridManagerRef,
    gridApiRef = _AdvanceTable$useGrid.gridApiRef,
    onGridReady = _AdvanceTable$useGrid.onGridReady;
  var _AdvanceTable$useRowS = AdvanceTable.useRowSelection(gridApiRef, _extends({}, rowSelectionOptions, {
      rowkey: LOWCODE_NODE_ID
    })),
    rowSelection = _AdvanceTable$useRowS.rowSelection,
    selectedKeys = _AdvanceTable$useRowS.selectedKeys;
  schema['x-data'] = _extends({}, schema['x-data'], {
    env: 'normal'
  });
  var prefixCls = usePrefixCls('array-avance-table');
  var _useStyle = useStyle(prefixCls),
    wrapSSR = _useStyle[0],
    hashId = _useStyle[1];
  var open = useOpen();
  useMemo(function () {
    if (!valueMode || valueMode === 'normal') return;
    var value = [];
    selected.children.forEach(function (child) {
      var _extends2;
      value.push(_extends({}, child.propsData, (_extends2 = {}, _extends2[LOWCODE_NODE_ID] = child.id, _extends2)));
    });
    field.setValue(value);
  }, []);
  var dataSource = Array.isArray(field.value) ? field.value.slice() : [];
  dataSource.forEach(function (item, index) {
    item[indexKey] = index;
  });
  useEffect(function () {
    if (!valueMode || valueMode === 'normal') return;
    var effects = function effects() {
      var valueChange = function valueChange(field) {
        var value = field.value;
        var key = field.path.toArr();
        console.log('-AdvanceTable-onFieldValueChange', key, value);
        var name = key[0],
          index = key[1],
          path = key.slice(2);
        selected.children.get(Number(index)).setPropValue(path.join('.'), value);
      };
      var path = field.path.concat('*').toString();
      onFieldDiffValueChange(path, valueChange);
    };
    field.form.addEffects('node-children-array-table', effects);
    return function () {
      field.form.removeEffects('node-children-array-table');
    };
  }, [field, selected, valueMode]);
  var sources = useArrayTableSources(field, schema);
  var columns = useArrayTableColumns(dataSource, field, sources);
  var addition = useAddition(schema);
  var batchRemove = useBatchRemove(schema);
  var handleRowDragEnd = useRowDragEnd(selected);
  var tableRef = useRef(null);
  var _useState = useState(undefined),
    tableHeight = _useState[0],
    setTableHeight = _useState[1];
  useEffect(function () {
    if (!field.data.open && tableRef.current) {
      var timer = setTimeout(function () {
        var _tableRef$current;
        clearTimeout(timer);
        var height = (_tableRef$current = tableRef.current) === null || _tableRef$current === void 0 ? void 0 : _tableRef$current.offsetHeight;
        setTableHeight(height);
      }, 300);
    }
  }, [field.data.open]);
  return wrapSSR(/*#__PURE__*/React.createElement(PreviewText.Placeholder, {
    value: ' '
  }, /*#__PURE__*/React.createElement(FieldDataSourceContext.Provider, {
    value: dataSource
  }, /*#__PURE__*/React.createElement(ValueModeContext.Provider, {
    value: valueMode
  }, /*#__PURE__*/React.createElement(GridManagerContext.Provider, {
    value: gridManagerRef
  }, /*#__PURE__*/React.createElement(RowSelectedContext.Provider, {
    value: selectedKeys
  }, /*#__PURE__*/React.createElement("div", {
    ref: ref,
    className: cls(prefixCls, hashId)
  }, /*#__PURE__*/React.createElement(ArrayBase, null, /*#__PURE__*/React.createElement(_Space, {
    className: cls(prefixCls + "-toobar")
  }, addition, batchRemove), /*#__PURE__*/React.createElement("div", {
    ref: tableRef,
    style: {
      height: field.data.open ? tableHeight : undefined
    }
  }, !field.data.open && /*#__PURE__*/React.createElement(AdvanceTable, _extends({
    editable: true,
    autoHeight: true,
    animateRows: true,
    rowMultiSelectWithClick: false,
    suppressSelectedBox: true,
    stopEditingWhenCellsLoseFocus: true,
    rowDragManaged: true
  }, props, {
    selectionColumnDef: {
      minWidth: 25,
      width: 25,
      maxWidth: 25
    },
    rowkey: LOWCODE_NODE_ID,
    rowSelection: rowSelection,
    onReady: onGridReady,
    className: cls(prefixCls + "-grid", className),
    columns: columns,
    dataSource: dataSource,
    onRowDragEnd: handleRowDragEnd
  }))), sources.map(function (column, key) {
    // 专门用来承接对Column的状态管理
    if (!isColumnComponent(column.schema)) return;
    return /*#__PURE__*/React.createElement(RecursionField, {
      name: column.name,
      schema: column.schema,
      onlyRenderSelf: true,
      key: key
    });
  }), open))))))));
});
var isOpenComponent = function isOpenComponent(schema) {
  var _schema$xComponent;
  return ((_schema$xComponent = schema['x-component']) === null || _schema$xComponent === void 0 ? void 0 : _schema$xComponent.indexOf('Open')) > -1;
};
var useOpen = function useOpen() {
  var schema = useFieldSchema();
  return schema.reduceProperties(function (open, schema, key) {
    if (isOpenComponent(schema)) {
      return /*#__PURE__*/React.createElement(RecursionField, {
        schema: schema,
        name: key
      });
    }
    return open;
  }, null);
};
var Open = /*#__PURE__*/memo(/*#__PURE__*/forwardRef(function (_ref2, ref) {
  var _array$field, _array$field2;
  var drawerProps = _ref2.drawerProps,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded2);
  var _useSlot = useSlot(),
    slotRef = _useSlot.slotRef;
  var self = useField();
  var array = ArrayBase.useArray();
  var _useState2 = useState(false),
    open = _useState2[0],
    setOpen = _useState2[1];
  var showDrawer = function showDrawer() {
    setOpen(true);
    array.field.setData(_extends({}, array.field.data, {
      open: true
    }));
  };
  var onClose = function onClose() {
    array.field.setData(_extends({}, array.field.data, {
      open: false
    }));
    setOpen(false);
  };
  var _useCommonUI2 = useCommonUI(),
    Drawer = _useCommonUI2.Drawer;
  var prefixCls = usePrefixCls('array-avance-table');
  var _useStyle2 = useStyle(prefixCls),
    wrapSSR = _useStyle2[0],
    hashId = _useStyle2[1];
  if (!array) return null;
  if (((_array$field = array.field) === null || _array$field === void 0 ? void 0 : _array$field.pattern) !== 'editable' && ((_array$field2 = array.field) === null || _array$field2 === void 0 ? void 0 : _array$field2.pattern) !== 'disabled') return null;
  var openButton = wrapSSR(/*#__PURE__*/React.createElement(_Button, _extends({
    type: "ghost"
  }, props, {
    style: _extends({
      padding: '0 6px 0 6px',
      width: 'auto',
      height: 'auto'
    }, props.style),
    disabled: self === null || self === void 0 ? void 0 : self.disabled,
    className: cls(prefixCls + "-open", hashId, self !== null && self !== void 0 && self.disabled ? prefixCls + "-open-disabled" : '', props.className),
    ref: ref,
    onClick: function onClick(e) {
      var _array$props;
      if ((_array$props = array.props) !== null && _array$props !== void 0 && _array$props.disabled) return;
      showDrawer();
      if (props.onClick) {
        props.onClick(e);
      }
    },
    icon: isUndef(props.icon) ? createIcon('fullscreen1') : props.icon
  }), props.title || self.title));
  var drawer = /*#__PURE__*/React.createElement(Drawer, _extends({}, drawerProps, {
    scrollBar: false,
    wrapperBody: false,
    push: false,
    className: cls(prefixCls + "-advance-drawer", drawerProps.className),
    classNames: {
      body: prefixCls + "-advance-drawer-body"
    },
    onClose: onClose,
    open: open
  }), /*#__PURE__*/React.createElement(RecordsScope, {
    getRecords: function getRecords() {
      return array.field.value;
    }
  }, /*#__PURE__*/React.createElement(FieldContext.Provider, {
    value: array.field
  }, /*#__PURE__*/React.createElement(SchemaContext.Provider, {
    value: array.schema
  }, /*#__PURE__*/React.createElement(AdvanceContent, array.field.componentProps)))));
  if (slotRef.current) {
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/createPortal(openButton, slotRef.current), drawer);
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, openButton, drawer);
}));
export var ArrayAdvanceTable = Object.assign(ArrayBase.mixin(InternalArrayAdvanceTable), {
  Column: Column,
  Addition: Addition,
  Navigation: Navigation,
  Open: Open,
  Action: Action,
  SidePanel: SidePanel,
  BatchRemove: BatchRemove
});
ArrayAdvanceTable.displayName = 'ArrayAdvanceTable';
export default ArrayAdvanceTable;
